Create html output with comparisons of MCMC results
make_MCMC_comparison_pages(
results,
dir = tempdir(),
pageComponents,
modelName = "model",
control,
params = NULL,
paramFilter = NULL,
MCMCs = NULL,
MCMCFilter = NULL,
plot = TRUE
)A list of objects returned from each page component plugin. For figures,
these contain a plottable object such as a ggplot object. For text,
these contain information for text output such as an xtable object.
A list of MCMCresult objects
such as returned by compareMCMCs.
A directory in which to place the html file and any
figure files used in it. This defaults to tempdir() (which
will be erased when the R session is closed).
Use dir = getwd() to use current working directory.
A list whose names are registered page
components and values are TRUE (to include a component) or
FALSE (to omit a component). Components can also be omitted by
leaving them out of the list.
A name to be used for the model in generated output.
A named list of control parameters.
Character vector of parameter names to include. If NULL,
all available parameter results will be included.
Expression suitable for use in dplyr::filter to subset
the parameters to include. The relevant column name is "Parameter". For
example, paramFilter=Parameter %in% c("alpha", "beta") will include only
alpha and beta. Subsetting parameters by the coarser params argument
will be done before subsetting by paramFilter.
Character vector of MCMC names to include. If NULL,
all available MCMCs will be included.
Expression suitable for use in dplyr::filter to subset
the MCMCs to include. The relevant column name is "MCMC". For example,
MCMCFilter=MCMC %in% c("MCMC1", "MCMC2") will include only MCMC1 and
MCMC2. Subsetting parameters by the coarser MCMCs argument will be
done before subsetting by MCMCFilter.
TRUE to generate results, FALSE not to do so. Use
of FALSE is useful if one wants to use the returned object
(including plottable components) in one's own way.
See package vignette for information about page components, including about default page components and how to write and register new page components.
To see built-in page components and their options, use
as.list(getPageComponents()).
The arguments params, paramFilter, MCMCs, and
MCMCFilter are passed to combineMetrics. Both
paramFilter and MCMCFilter are passed as expressions. One can
call combineMetrics directly (with results as the first argument and any
of these four arguments) to see the results tables that will be used to
create figures.